@@ -3,12 +3,14 @@
 from ...data_checks.raw.check_predictor_lists import (  # noqa
     check_feature_combinations_return_correct_dfs,
 )
+from .load_admissions import *  # noqa
 from .load_coercion import *  # noqa
 from .load_demographic import *  # noqa
 from .load_diagnoses import *  # noqa
 from .load_ids import *  # noqa
 from .load_lab_results import *  # noqa
 from .load_medications import *  # noqa
+from .load_structured_sfi import *  # noqa
 from .load_t2d_outcomes import *  # noqa
 from .load_visits import *  # noqa
 from .sql_load import *  # noqa
